@@ -2,6 +2,6 @@
 from relpath import add_import_path
 add_import_path("../")
 # task management tool
-from _develop_tskr import tskr
+from _develop_tskr import tskr_command
 
-tskr()
+tskr_command()
